using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using SharpCharts.Base.Data;

namespace SharpCharts.Base.MarketWatch
{
	
    public class DeltaChange : ScannerBase
    {
    
    	double currentOptionPrice = 0.0d;
    	double currentUnderlyingPrice = 0.0d;
    	double delta = 0.0d;
    	
        public DeltaChange()
        {
            
        }

        protected override void OnStateChange()
        {
            switch (base.State)
            {
            	
                case SharpCharts.Base.SharpScript.State.Finalize:
                    break;
                case SharpCharts.Base.SharpScript.State.Initialize:
					
					if (base.Instrument.InstrumentDefination.InstrumentType != InstrumentType.Options)
						throw new Exception("Primary instrument must be options");

					//add a secendory instrument, of the underlying. The string format of the instrument is defined here
					//http://www.arthachitra.com/support/ac1/Help/html/115dd4d0-e2f7-4ee4-9a14-1e7bde557cde.htm
					AddInstrument("^NIFTY NSE");
                    
                    base.IsLevel1Subscribed = true;
                    break;
            }
        }
        
		protected override void OnLevel1(int idx, RealTimeDataEventArgs e)
		{
			
			if (e.MarketDataType == MarketDataType.Delta)
			{
				this.delta = e.Price;
				return;
			}
			
			//we are only interested in last traded price
			if (e.MarketDataType != MarketDataType.Last)
				return;
				
			if (idx == 0) //gets the quotes of the primary instrument
			{
				this.currentOptionPrice = e.Price;
			}
			else if (idx == 1) // get the quotes of the underlying / secondary instrument
			{
				this.currentUnderlyingPrice = e.Price;
			}
			
			if (this.delta == 0.0d || this.currentUnderlyingPrice == 0.0d || this.currentOptionPrice == 0.0d || this.ProjectedValueOfUnderlying == 0.0d)
				return;
			
			
			//calculate the value
			double change = (this.ProjectedValueOfUnderlying - this.currentUnderlyingPrice) * this.delta;
			this.DisplayValue = this.currentOptionPrice + change;
		}
		
		
		private double projectedValueOfUnderlying = 0.0d;
		
		public double ProjectedValueOfUnderlying
		{
			get { return projectedValueOfUnderlying; }
			set
			{
				projectedValueOfUnderlying = Math.Max(0.0d, value);
				NotifyPropertyChanged("ProjectedValueOfUnderlying");
			}
		}
		
		public override string DisplayName
		{
			get { return "Delta @ " + this.ProjectedValueOfUnderlying.ToString(); }
		} 
		
		public override string HeaderString
		{
			get { return "Price @ " + this.ProjectedValueOfUnderlying.ToString(); }
		}
		
		
		
    }
}